@@ -9,9 +9,9 @@ import pyplumio
 async def main() -> None:
     """Connect and print out device sensors and parameters."""
     async with pyplumio.open_serial_connection("/dev/ttyUSB0", 115200) as connection:
-        device = await connection.get_device("ecomax")
-        sensors = await device.get_value("sensors")
-        parameters = await device.get_value("parameters")
+        device = await connection.get("ecomax")
+        sensors = await device.get("sensors")
+        parameters = await device.get("parameters")
 
     print(sensors)
     print(parameters)
