@@ -12,10 +12,9 @@ from pyplumio.exceptions import ParameterNotFoundError, UnknownDeviceError
 from pyplumio.frames import DataFrameDescription, Frame, Request, get_frame_handler
 from pyplumio.helpers.event_manager import EventManager
 from pyplumio.helpers.factory import factory
-from pyplumio.helpers.network_info import NetworkInfo
-from pyplumio.helpers.parameter import Parameter
-from pyplumio.helpers.typing import NumericType
-from pyplumio.structures.network_info import ATTR_NETWORK
+from pyplumio.helpers.parameter import SET_RETRIES, Parameter
+from pyplumio.helpers.typing import ParameterValueType
+from pyplumio.structures.network_info import ATTR_NETWORK, NetworkInfo
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -81,7 +80,7 @@ class Device(EventManager):
         return await self.get(name, timeout)
 
     async def set_value(
-        self, name: str, value: NumericType, timeout: float | None = None
+        self, name: str, value: ParameterValueType, timeout: float | None = None
     ) -> bool:
         """Sets a value."""
         warn(
@@ -94,7 +93,7 @@ class Device(EventManager):
         return await self.set(name, value, timeout)
 
     def set_value_nowait(
-        self, name: str, value: NumericType, timeout: float | None = None
+        self, name: str, value: ParameterValueType, timeout: float | None = None
     ) -> None:
         """Sets a value without waiting."""
         warn(
@@ -107,22 +106,30 @@ class Device(EventManager):
         self.set_nowait(name, value, timeout)
 
     async def set(
-        self, name: str, value: NumericType, timeout: float | None = None
+        self,
+        name: str,
+        value: ParameterValueType,
+        timeout: float | None = None,
+        retries: int = SET_RETRIES,
     ) -> bool:
         """Set a parameter value. Name should point
         to a valid parameter object, otherwise raises
         ParameterNotFoundError."""
-        parameter = await self.get(name)
+        parameter = await self.get(name, timeout=timeout)
         if not isinstance(parameter, Parameter):
             raise ParameterNotFoundError(f"Parameter not found ({name})")
 
-        return await parameter.set(value)
+        return await parameter.set(value, retries=retries)
 
     def set_nowait(
-        self, name: str, value: NumericType, timeout: float | None = None
+        self,
+        name: str,
+        value: ParameterValueType,
+        timeout: float | None = None,
+        retries: int = SET_RETRIES,
     ) -> None:
         """Set a parameter value without waiting for the result."""
-        self.create_task(self.set(name, value, timeout))
+        self.create_task(self.set(name, value, timeout, retries))
 
 
 class Addressable(Device):
@@ -147,7 +154,7 @@ class Addressable(Device):
 
         if frame.data is not None:
             for name, value in frame.data.items():
-                self.dispatch(name, value)
+                self.dispatch_nowait(name, value)
 
     async def async_setup(self) -> bool:
         """Setup addressable device object."""
@@ -161,11 +168,11 @@ class Addressable(Device):
                 },
                 return_exceptions=False,
             )
-            await self.async_dispatch(ATTR_LOADED, True)
+            await self.dispatch(ATTR_LOADED, True)
             return True
         except ValueError as e:
             _LOGGER.error("Request failed: %s", e)
-            await self.async_dispatch(ATTR_LOADED, False)
+            await self.dispatch(ATTR_LOADED, False)
             return False
 
     async def request(
