@@ -22,9 +22,8 @@ from pyplumio.devices import Addressable, Mixer, Thermostat
 from pyplumio.filters import on_change
 from pyplumio.frames import DataFrameDescription, get_frame_handler, is_known_frame_type
 from pyplumio.helpers.factory import factory
-from pyplumio.helpers.network_info import NetworkInfo
 from pyplumio.helpers.schedule import Schedule, ScheduleDay
-from pyplumio.helpers.typing import EventDataType, ParameterDataType, VersionsInfoType
+from pyplumio.helpers.typing import EventDataType, ParameterDataType
 from pyplumio.structures import StructureDecoder
 from pyplumio.structures.alerts import ATTR_ALERTS
 from pyplumio.structures.data_schema import ATTR_SCHEMA
@@ -45,6 +44,7 @@ from pyplumio.structures.mixer_parameters import (
     ECOMAX_P_MIXER_PARAMETERS,
 )
 from pyplumio.structures.mixer_sensors import ATTR_MIXER_SENSORS
+from pyplumio.structures.network_info import NetworkInfo
 from pyplumio.structures.product_info import ATTR_PRODUCT
 from pyplumio.structures.regulator_data import ATTR_REGDATA, ATTR_REGDATA_DECODER
 from pyplumio.structures.schedules import (
@@ -65,7 +65,7 @@ ATTR_MIXERS: Final = "mixers"
 ATTR_THERMOSTATS: Final = "thermostats"
 ATTR_FUEL_BURNED: Final = "fuel_burned"
 
-MAX_TIME_SINCE_LAST_FUEL_DATA: Final = 300
+MAX_TIME_SINCE_LAST_FUEL_UPDATE_NS: Final = 300 * 1000000000
 
 DATA_FRAME_TYPES: tuple[DataFrameDescription, ...] = (
     DataFrameDescription(frame_type=FrameType.REQUEST_UID, provides=ATTR_PRODUCT),
@@ -96,15 +96,15 @@ class EcoMAX(Addressable):
     """Represents ecoMAX controller."""
 
     address: ClassVar[int] = DeviceType.ECOMAX
-    _frame_versions: VersionsInfoType
+    _frame_versions: dict[int, int]
     _frame_types: tuple[DataFrameDescription, ...] = DATA_FRAME_TYPES
-    _fuel_burned_timestamp: float = 0.0
+    _fuel_burned_timestamp_ns: int = 0
 
     def __init__(self, queue: asyncio.Queue, network: NetworkInfo):
         """Initialize new ecoMAX object."""
         super().__init__(queue, network)
         self._frame_versions = {}
-        self._fuel_burned_timestamp = time.time()
+        self._fuel_burned_timestamp_ns = time.perf_counter_ns()
         self.subscribe(ATTR_SENSORS, self._add_ecomax_sensors)
         self.subscribe(ATTR_STATE, on_change(self._add_ecomax_control_parameter))
         self.subscribe(ATTR_FUEL_CONSUMPTION, self._add_burned_fuel_counter)
@@ -127,7 +127,7 @@ class EcoMAX(Addressable):
         await self.wait_for(ATTR_SENSORS)
         return await super().async_setup()
 
-    async def _update_frame_versions(self, versions: VersionsInfoType) -> None:
+    async def _update_frame_versions(self, versions: dict[int, int]) -> None:
         """Check versions and fetch outdated frames."""
         for frame_type, version in versions.items():
             if is_known_frame_type(frame_type) and (
@@ -149,7 +149,7 @@ class EcoMAX(Addressable):
             mixers[index] = mixer
             if len(mixers) == mixer_count:
                 # All mixers were processed, notify callbacks and getters.
-                self.dispatch(ATTR_MIXERS, mixers)
+                self.dispatch_nowait(ATTR_MIXERS, mixers)
 
         return mixer
 
@@ -164,14 +164,14 @@ class EcoMAX(Addressable):
             thermostats[index] = thermostat
             if len(thermostats) == thermostat_count:
                 # All thermostats were processed, notify callbacks and getters.
-                self.dispatch(ATTR_THERMOSTATS, thermostats)
+                self.dispatch_nowait(ATTR_THERMOSTATS, thermostats)
 
         return thermostat
 
     async def _add_ecomax_sensors(self, sensors: EventDataType) -> bool:
         """Add ecomax sensor values to the device data."""
         for name, value in sensors.items():
-            await self.async_dispatch(name, value)
+            await self.dispatch(name, value)
 
         return True
 
@@ -194,7 +194,7 @@ class EcoMAX(Addressable):
                 min_value=value[1],
                 max_value=value[2],
             )
-            await self.async_dispatch(description.name, parameter)
+            await self.dispatch(description.name, parameter)
 
         return True
 
@@ -205,7 +205,7 @@ class EcoMAX(Addressable):
         for mixer_index, mixer_sensors in sensors:
             mixer = self._get_mixer(mixer_index, len(sensors))
             for name, value in mixer_sensors.items():
-                await mixer.async_dispatch(name, value)
+                await mixer.dispatch(name, value)
 
         return True
 
@@ -235,7 +235,7 @@ class EcoMAX(Addressable):
                     min_value=value[1],
                     max_value=value[2],
                 )
-                await mixer.async_dispatch(description.name, parameter)
+                await mixer.dispatch(description.name, parameter)
 
         return True
 
@@ -246,7 +246,7 @@ class EcoMAX(Addressable):
         for thermostat_index, thermostat_sensors in sensors:
             thermostat = self._get_thermostat(thermostat_index, len(sensors))
             for name, value in thermostat_sensors.items():
-                await thermostat.async_dispatch(name, value)
+                await thermostat.dispatch(name, value)
 
         return True
 
@@ -272,7 +272,7 @@ class EcoMAX(Addressable):
                     max_value=value[2],
                     offset=(thermostat_index * len(thermostat_parameters)),
                 )
-                await thermostat.async_dispatch(description.name, parameter)
+                await thermostat.dispatch(description.name, parameter)
 
         return True
 
@@ -295,7 +295,7 @@ class EcoMAX(Addressable):
         """Decode thermostat parameters."""
         data = decoder.decode(decoder.frame.message, data=self.data)[0]
         for field in (ATTR_THERMOSTAT_PROFILE, ATTR_THERMOSTAT_PARAMETERS):
-            await self.async_dispatch(field, data[field])
+            await self.dispatch(field, data[field])
 
         return True
 
@@ -308,29 +308,29 @@ class EcoMAX(Addressable):
             min_value=STATE_OFF,
             max_value=STATE_ON,
         )
-        await self.async_dispatch(ECOMAX_CONTROL_PARAMETER.name, parameter)
+        await self.dispatch(ECOMAX_CONTROL_PARAMETER.name, parameter)
 
     async def _add_burned_fuel_counter(self, fuel_consumption: float) -> None:
         """Add burned fuel counter."""
-        current_timestamp = time.time()
-        seconds_passed = current_timestamp - self._fuel_burned_timestamp
-        if 0 <= seconds_passed < MAX_TIME_SINCE_LAST_FUEL_DATA:
-            fuel_burned = (fuel_consumption / 3600) * seconds_passed
-            await self.async_dispatch(ATTR_FUEL_BURNED, fuel_burned)
+        current_timestamp_ns = time.perf_counter_ns()
+        time_passed_ns = current_timestamp_ns - self._fuel_burned_timestamp_ns
+        if time_passed_ns < MAX_TIME_SINCE_LAST_FUEL_UPDATE_NS:
+            fuel_burned = fuel_consumption / (3600 * 1000000000) * time_passed_ns
+            await self.dispatch(ATTR_FUEL_BURNED, fuel_burned)
         else:
             _LOGGER.warning(
                 "Skipping outdated fuel consumption data, was %i seconds old",
-                seconds_passed,
+                time_passed_ns / 1000000000,
             )
 
-        self._fuel_burned_timestamp = current_timestamp
+        self._fuel_burned_timestamp_ns = current_timestamp_ns
 
     async def _decode_regulator_data(self, decoder: StructureDecoder) -> bool:
         """Decode regulator data."""
         data = decoder.decode(decoder.frame.message, data=self.data)[0]
         for field in (ATTR_FRAME_VERSIONS, ATTR_REGDATA):
             try:
-                await self.async_dispatch(field, data[field])
+                await self.dispatch(field, data[field])
             except KeyError:
                 continue
 
@@ -349,7 +349,7 @@ class EcoMAX(Addressable):
                 min_value=value[1],
                 max_value=value[2],
             )
-            await self.async_dispatch(description.name, parameter)
+            await self.dispatch(description.name, parameter)
 
         return True
 
@@ -388,6 +388,14 @@ class EcoMAX(Addressable):
             _LOGGER.error("ecoMAX control is not available, please try later")
             return False
 
+    def turn_on_nowait(self) -> None:
+        """Turn on the ecoMAX controller without waiting."""
+        self.create_task(self.turn_on())
+
+    def turn_off_nowait(self) -> None:
+        """Turn off the ecoMAX controller without waiting."""
+        self.create_task(self.turn_off())
+
     async def shutdown(self) -> None:
         """Cancel scheduled tasks for root and sub devices."""
         mixers = self.get_nowait(ATTR_MIXERS, {})
