@@ -5,7 +5,7 @@ from typing import Final
 
 from pyplumio import util
 from pyplumio.const import FrameType
-from pyplumio.helpers.typing import EventDataType, VersionsInfoType
+from pyplumio.helpers.typing import EventDataType
 from pyplumio.structures import StructureDecoder, ensure_device_data
 
 ATTR_FRAME_VERSIONS: Final = "frame_versions"
@@ -18,7 +18,7 @@ class FrameVersionsStructure(StructureDecoder):
         self, message: bytearray, offset: int = 0, data: EventDataType | None = None
     ) -> tuple[EventDataType, int]:
         """Decode bytes and return message data and offset."""
-        frame_versions: VersionsInfoType = {}
+        frame_versions: dict[int, int] = {}
         frame_count = message[offset]
         offset += 1
         for _ in range(frame_count):
