@@ -12,7 +12,7 @@ ATTR_FAN: Final = "fan"
 ATTR_FEEDER: Final = "feeder"
 ATTR_HEATING_PUMP: Final = "heating_pump"
 ATTR_WATER_HEATER_PUMP: Final = "water_heater_pump"
-ATTR_CIRCULATION_PUMP: Final = "ciculation_pump"
+ATTR_CIRCULATION_PUMP: Final = "circulation_pump"
 ATTR_LIGHTER: Final = "lighter"
 ATTR_ALARM: Final = "alarm"
 ATTR_OUTER_BOILER: Final = "outer_boiler"
