@@ -52,7 +52,6 @@ from pyplumio.frames.responses import (
     SchedulesResponse,
     ThermostatParametersResponse,
 )
-from pyplumio.helpers.network_info import NetworkInfo
 from pyplumio.helpers.parameter import Parameter
 from pyplumio.helpers.schedule import Schedule
 from pyplumio.helpers.typing import EventDataType
@@ -67,6 +66,7 @@ from pyplumio.structures.mixer_parameters import (
     MixerBinaryParameter,
     MixerParameter,
 )
+from pyplumio.structures.network_info import NetworkInfo
 from pyplumio.structures.regulator_data import ATTR_REGDATA, RegulatorData
 from pyplumio.structures.schedules import (
     ATTR_SCHEDULE_PARAMETER,
@@ -255,7 +255,10 @@ async def test_ecomax_parameters_callbacks(
     assert airflow_power_50.max_value == 60.0
 
 
-@patch("time.time", side_effect=(0, 10, 600, 610))
+@patch(
+    "time.perf_counter_ns",
+    side_effect=(0, 10 * 1000000000, 600 * 1000000000, 610 * 1000000000),
+)
 async def test_fuel_consumption_callbacks(mock_time, caplog) -> None:
     """Test callbacks that are dispatchd on received fuel consumption."""
     ecomax = EcoMAX(asyncio.Queue(), network=NetworkInfo())
@@ -570,17 +573,17 @@ async def test_set(ecomax: EcoMAX, messages: dict[FrameType, bytearray]) -> None
         await ecomax.set("bar", 1)
 
 
-async def test_turn_on_off(ecomax: EcoMAX, caplog) -> None:
-    """Test turning the controller on/off."""
-    # Test turning on.
+async def test_turn_on(ecomax: EcoMAX, caplog) -> None:
+    """Test turning the controller on."""
     assert not await ecomax.turn_on()
     assert "ecoMAX control is not available" in caplog.text
     ecomax.data[ATTR_ECOMAX_CONTROL] = AsyncMock()
     assert await ecomax.turn_on()
     ecomax.data[ATTR_ECOMAX_CONTROL].turn_on.assert_awaited_once()
 
-    # Test turning off.
-    del ecomax.data[ATTR_ECOMAX_CONTROL]
+
+async def test_turn_off(ecomax: EcoMAX, caplog) -> None:
+    """Test turning the controller off."""
     await ecomax.turn_off()
     assert "ecoMAX control is not available" in caplog.text
     ecomax.data[ATTR_ECOMAX_CONTROL] = AsyncMock()
@@ -588,6 +591,26 @@ async def test_turn_on_off(ecomax: EcoMAX, caplog) -> None:
     ecomax.data[ATTR_ECOMAX_CONTROL].turn_off.assert_awaited_once()
 
 
+@patch("pyplumio.devices.ecomax.EcoMAX.create_task")
+@patch("pyplumio.devices.ecomax.EcoMAX.turn_on", new_callable=Mock)
+async def test_turn_on_nowait(mock_create_task, mock_turn_on, ecomax: EcoMAX) -> None:
+    """Test turning the controller on without waiting."""
+    ecomax.turn_on_nowait()
+    await ecomax.wait_until_done()
+    mock_create_task.assert_called_once()
+    mock_turn_on.assert_called_once()
+
+
+@patch("pyplumio.devices.ecomax.EcoMAX.create_task")
+@patch("pyplumio.devices.ecomax.EcoMAX.turn_off", new_callable=Mock)
+async def test_turn_off_nowait(mock_create_task, mock_turn_off, ecomax: EcoMAX) -> None:
+    """Test turning the controller on without waiting."""
+    ecomax.turn_off_nowait()
+    await ecomax.wait_until_done()
+    mock_create_task.assert_called_once()
+    mock_turn_off.assert_called_once()
+
+
 async def test_shutdown(ecomax: EcoMAX, messages: dict[FrameType, bytearray]) -> None:
     """Test device tasks shutdown."""
     ecomax.handle_frame(
